@@ -2,11 +2,12 @@ package Business::GoCardless;
 
 =head1 NAME
 
-Business::GoCardless
+Business::GoCardless - Perl library for interacting with the GoCardless API
+(https://gocardless.com)
 
 =head1 VERSION
 
-0.01
+0.02
 
 =head1 DESCRIPTION
 
